@@ -1,5 +1,6 @@
 from typing import Any, Dict
-from vorta.i18n import trans_late
+from vorta.config import LOG_DIR
+from vorta.i18n import trans_late, translate
 from vorta.utils import borg_compat
 from .borg_job import BorgJob
 
@@ -7,7 +8,9 @@ from .borg_job import BorgJob
 class BorgCompactJob(BorgJob):
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_progress_event.emit(self.tr('Starting repository compaction...'))
+        self.app.backup_progress_event.emit(
+            f"[{self.params['profile_name']} {self.tr('Starting repository compaction...')}]"
+        )
 
     def finished_event(self, result: Dict[str, Any]):
         """
@@ -21,9 +24,14 @@ class BorgCompactJob(BorgJob):
         self.app.backup_finished_event.emit(result)
         self.result.emit(result)
         if result['returncode'] != 0:
-            self.app.backup_progress_event.emit(self.tr('Errors during compaction. See logs for details.'))
+            self.app.backup_progress_event.emit(
+                f"[{self.params['profile_name']}] "
+                + translate(
+                    'BorgCompactJob', 'Errors during compaction. See the <a href="{0}">logs</a> for details.'
+                ).format(LOG_DIR.as_uri())
+            )
         else:
-            self.app.backup_progress_event.emit(self.tr('Compaction completed.'))
+            self.app.backup_progress_event.emit(f"[{self.params['profile_name']}] {self.tr('Compaction completed.')}")
 
     @classmethod
     def prepare(cls, profile):
@@ -38,8 +46,11 @@ class BorgCompactJob(BorgJob):
             ret['message'] = trans_late('messages', 'This feature needs Borg 1.2.0 or higher.')
             return ret
 
-        cmd = ['borg', '--info', '--log-json', 'compact', '--cleanup-commits']
-        cmd.append(f'{profile.repo.url}')
+        cmd = ['borg', '--info', '--log-json', 'compact', '--progress']
+        if borg_compat.check('V2'):
+            cmd = cmd + ["-r", profile.repo.url]
+        else:
+            cmd.append(f'{profile.repo.url}')
 
         ret['ok'] = True
         ret['cmd'] = cmd
