@@ -5,11 +5,15 @@ from .borg_job import BorgJob
 class BorgDiffJob(BorgJob):
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_progress_event.emit(self.tr('Requesting differences between archives…'))
+        self.app.backup_progress_event.emit(
+            f"[{self.params['profile_name']}] {self.tr('Requesting differences between archives…')}"
+        )
 
     def finished_event(self, result):
         self.app.backup_finished_event.emit(result)
-        self.app.backup_progress_event.emit(self.tr('Obtained differences between archives.'))
+        self.app.backup_progress_event.emit(
+            f"[{self.params['profile_name']}] {self.tr('Obtained differences between archives.')}"
+        )
         self.result.emit(result)
 
     @classmethod
@@ -24,7 +28,11 @@ class BorgDiffJob(BorgJob):
             ret['cmd'].append('--json-lines')
             ret['json_lines'] = True
 
-        ret['cmd'].extend([f'{profile.repo.url}::{archive_name_1}', f'{archive_name_2}'])
+        if borg_compat.check('V2'):
+            ret['cmd'].extend(['-r', profile.repo.url, archive_name_1, archive_name_2])
+        else:
+            ret['cmd'].extend([f'{profile.repo.url}::{archive_name_1}', archive_name_2])
+
         ret['ok'] = True
         ret['archive_name_older'] = archive_name_1
         ret['archive_name_newer'] = archive_name_2
