@@ -1,5 +1,4 @@
 import logging
-import os.path
 import sys
 from datetime import timedelta
 from typing import Dict, Optional
@@ -31,8 +30,16 @@ from vorta.borg.mount import BorgMountJob
 from vorta.borg.prune import BorgPruneJob
 from vorta.borg.rename import BorgRenameJob
 from vorta.borg.umount import BorgUmountJob
+from vorta.i18n import translate
 from vorta.store.models import ArchiveModel, BackupProfileMixin
-from vorta.utils import choose_file_dialog, format_archive_name, get_asset, get_mount_points, pretty_bytes
+from vorta.utils import (
+    choose_file_dialog,
+    find_best_unit_for_sizes,
+    format_archive_name,
+    get_asset,
+    get_mount_points,
+    pretty_bytes,
+)
 from vorta.views import diff_result, extract_dialog
 from vorta.views.diff_result import DiffResultDialog, DiffTree
 from vorta.views.extract_dialog import ExtractDialog, ExtractTree
@@ -45,6 +52,10 @@ ArchiveTabUI, ArchiveTabBase = uic.loadUiType(uifile)
 logger = logging.getLogger(__name__)
 
 
+#: The number of decimal digits to show in the size column
+SIZE_DECIMAL_DIGITS = 1
+
+
 class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
     prune_intervals = ['hour', 'day', 'week', 'month', 'year']
 
@@ -52,7 +63,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         """Init."""
         super().__init__(parent)
         self.setupUi(parent)
-        self.mount_points = {}  # mount points of archives
+        self.mount_points = {}  # mapping of archive name to mount point
         self.repo_mount_point: Optional[str] = None  # mount point of whole repo
         self.menu = None
         self.app = app
@@ -220,8 +231,10 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             self.bList,
             self.bPrune,
             self.bDiff,
-            self.fArchiveActions,
             self.bMountRepo,
+            self.bDelete,
+            self.compactButton,
+            self.fArchiveActions,
         ]:
             button.setEnabled(enabled)
             button.repaint()
@@ -243,12 +256,15 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
             sorting = self.archiveTable.isSortingEnabled()
             self.archiveTable.setSortingEnabled(False)
+            best_unit = find_best_unit_for_sizes((a.size for a in archives), precision=SIZE_DECIMAL_DIGITS)
             for row, archive in enumerate(archives):
                 self.archiveTable.insertRow(row)
 
                 formatted_time = archive.time.strftime('%Y-%m-%d %H:%M')
                 self.archiveTable.setItem(row, 0, QTableWidgetItem(formatted_time))
-                self.archiveTable.setItem(row, 1, SizeItem(pretty_bytes(archive.size)))
+                self.archiveTable.setItem(
+                    row, 1, SizeItem(pretty_bytes(archive.size, fixed_unit=best_unit, precision=SIZE_DECIMAL_DIGITS))
+                )
                 if archive.duration is not None:
                     formatted_duration = str(timedelta(seconds=round(archive.duration)))
                 else:
@@ -308,17 +324,22 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         # Toggle archive actions frame
         layout: QLayout = self.fArchiveActions.layout()
 
+        # task in progress -> disable all
+        reason = ""
+        if not self.repoactions_enabled:
+            reason = self.tr("(borg already running)")
+
         # toggle delete button
-        if len(indexes) > 0:
+        if self.repoactions_enabled and len(indexes) > 0:
             self.bDelete.setEnabled(True)
             self.bDelete.setToolTip(self.tooltip_dict.get(self.bDelete, ""))
         else:
             self.bDelete.setEnabled(False)
             tooltip = self.tooltip_dict[self.bDelete]
-            self.bDelete.setToolTip(tooltip + " " + self.tr("(Select minimum one archive)"))
+            self.bDelete.setToolTip(tooltip + " " + reason or self.tr("(Select minimum one archive)"))
 
         # Toggle diff button
-        if len(indexes) == 2:
+        if self.repoactions_enabled and len(indexes) == 2:
             # Enable diff button
             self.bDiff.setEnabled(True)
             self.bDiff.setToolTip(self.tooltip_dict.get(self.bDiff, ""))
@@ -327,9 +348,9 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             self.bDiff.setEnabled(False)
 
             tooltip = self.tooltip_dict[self.bDiff]
-            self.bDiff.setToolTip(tooltip + " " + self.tr("(Select two archives)"))
+            self.bDiff.setToolTip(tooltip + " " + reason or self.tr("(Select two archives)"))
 
-        if len(indexes) == 1:
+        if self.repoactions_enabled and len(indexes) == 1:
             # Enable archive actions
             self.fArchiveActions.setEnabled(True)
 
@@ -340,6 +361,8 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             # refresh bMountArchive for the selected archive
             self.bmountarchive_refresh()
         else:
+            reason = reason or self.tr("(Select exactly one archive)")
+
             # too few or too many selected.
             self.fArchiveActions.setEnabled(False)
 
@@ -348,12 +371,12 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 tooltip = widget.toolTip()
 
                 tooltip = self.tooltip_dict.setdefault(widget, tooltip)
-                widget.setToolTip(tooltip + " " + self.tr("(Select exactly one archive)"))
+                widget.setToolTip(tooltip + " " + reason)
 
             # special treatment for dynamic mount/unmount button.
             self.bmountarchive_refresh()
             tooltip = self.bMountArchive.toolTip()
-            self.bMountArchive.setToolTip(tooltip + " " + self.tr("(Select exactly one archive)"))
+            self.bMountArchive.setToolTip(tooltip + " " + reason)
 
     def archive_copy(self, index=None):
         """
@@ -565,17 +588,11 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             The archive to mount or None, by default None
         """
         profile = self.profile()
-        params = BorgMountJob.prepare(profile)
+        params = BorgMountJob.prepare(profile, archive=archive_name)
         if not params['ok']:
             self._set_status(params['message'])
             return
 
-        if archive_name:
-            # mount archive
-            params['cmd'][-1] += f'::{archive_name}'
-            params['current_archive'] = archive_name
-        # else mount complete repo
-
         def receive():
             mount_point = dialog.selectedFiles()
             if mount_point:
@@ -598,13 +615,12 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
             mount_point = result['params']['mount_point']
 
-            if result['params'].get('current_archive'):
+            if result['params'].get('mounted_archive'):
                 # archive was mounted
-                archive_name = result['params']['current_archive']
+                archive_name = result['params']['mounted_archive']
                 self.mount_points[archive_name] = mount_point
 
                 # update column in table
-                archive_name = result['params']['current_archive']
                 row = self.row_of_archive(archive_name)
                 item = QTableWidgetItem(result['cmd'][-1])
                 self.archiveTable.setItem(row, 3, item)
@@ -638,25 +654,15 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
         if mount_point is not None:
             profile = self.profile()
-            params = BorgUmountJob.prepare(profile)
+            params = BorgUmountJob.prepare(profile, mount_point, archive_name=archive_name)
             if not params['ok']:
-                self._set_status(params['message'])
+                self._set_status(translate('message', params['message']))
                 return
 
-            if archive_name:
-                params['current_archive'] = archive_name
-            params['mount_point'] = mount_point
-
-            if os.path.normpath(mount_point) in params['active_mount_points']:
-                params['cmd'].append(mount_point)
-
-                job = BorgUmountJob(params['cmd'], params, self.profile().repo.id)
-                job.updated.connect(self.mountErrors.setText)
-                job.result.connect(self.umount_result)
-                self.app.jobs_manager.add_job(job)
-            else:
-                self._set_status(self.tr('Mount point not active.'))
-                return
+            job = BorgUmountJob(params['cmd'], params, self.profile().repo.id)
+            job.updated.connect(self.mountErrors.setText)
+            job.result.connect(self.umount_result)
+            self.app.jobs_manager.add_job(job)
 
     def umount_result(self, result):
         self._toggle_all_buttons(True)
@@ -907,10 +913,6 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
     def rename_action(self):
         profile = self.profile()
-        params = BorgRenameJob.prepare(profile)
-        if not params['ok']:
-            self._set_status(params['message'])
-            return
 
         archive_name = self.selected_archive_name()
         if archive_name is not None:
@@ -933,8 +935,10 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 self._set_status(self.tr('An archive with this name already exists.'))
                 return
 
-            params['cmd'][-1] += f'::{archive_name}'
-            params['cmd'].append(new_name)
+            params = BorgRenameJob.prepare(profile, archive_name, new_name)
+            if not params['ok']:
+                self._set_status(params['message'])
+
             job = BorgRenameJob(params['cmd'], params, self.profile().repo.id)
             job.updated.connect(self._set_status)
             job.result.connect(self.rename_result)
